@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: /sd/opensource/trunk/Audio-Scan/libid3tag/field.c 52786 2009-04-07T15:38:04.236288Z andy  $
+ * $Id: /sd/opensource/trunk/Audio-Scan/libid3tag/field.c 59610 2009-10-17T01:38:41.390924Z andy  $
  */
 
 # ifdef HAVE_CONFIG_H
@@ -615,7 +615,7 @@ int id3_field_setstrings(union id3_field *field,
     return 0;
 
 #ifdef _MSC_VER
-  Newx(strings, length, id3_ucs4_t *);
+  New(0, strings, length, id3_ucs4_t *);
 #else
   strings = malloc(length * sizeof(*strings));
 #endif
@@ -746,7 +746,7 @@ int id3_field_setbinarydata(union id3_field *field,
     mem = 0;
   else {
 #ifdef _MSC_VER
-    Newx(mem, length, id3_byte_t);
+    New(0, mem, length, id3_byte_t);
 #else
     mem = malloc(length);
 #endif
