@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: /sd/opensource/trunk/Audio-Scan/libid3tag/utf8.c 52786 2009-04-07T15:38:04.236288Z andy  $
+ * $Id: /sd/opensource/trunk/Audio-Scan/libid3tag/utf8.c 59610 2009-10-17T01:38:41.390924Z andy  $
  */
 
 # ifdef HAVE_CONFIG_H
@@ -121,7 +121,7 @@ id3_ucs4_t *id3_utf8_ucs4duplicate(id3_utf8_t const *utf8)
   id3_ucs4_t *ucs4;
 
 #ifdef _MSC_VER
-  Newx(ucs4, id3_utf8_length(utf8) + 1, id3_ucs4_t);
+  New(0, ucs4, id3_utf8_length(utf8) + 1, id3_ucs4_t);
 #else
   ucs4 = malloc((id3_utf8_length(utf8) + 1) * sizeof(*ucs4));
 #endif
@@ -350,7 +350,7 @@ id3_ucs4_t *id3_utf8_deserialize(id3_byte_t const **ptr, id3_length_t length)
   end = *ptr + length;
 
 #ifdef _MSC_VER
-  Newx(utf8, length + 1, id3_utf8_t);
+  New(0, utf8, length + 1, id3_utf8_t);
 #else
   utf8 = malloc((length + 1) * sizeof(*utf8));
 #endif
@@ -364,7 +364,7 @@ id3_ucs4_t *id3_utf8_deserialize(id3_byte_t const **ptr, id3_length_t length)
   *utf8ptr = 0;
 
 #ifdef _MSC_VER
-  Newx(ucs4, id3_utf8_length(utf8) + 1, id3_ucs4_t);
+  New(0, ucs4, id3_utf8_length(utf8) + 1, id3_ucs4_t);
 #else
   ucs4 = malloc((id3_utf8_length(utf8) + 1) * sizeof(*ucs4));
 #endif
